==> lxqt-session_0.10.0.orig.tar.gz: lxqt-session-0.10.0/lxqt-config-session/translations/lxqt-config-session_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Komut:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Sistem çekmecesi için bekleyin</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Uygulama Seç</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="192"/>
        <source>Global Autostart</source>
        <translation>Genel Kendiliğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="194"/>
        <source>LXQt Autostart</source>
        <translation>LXQt Kendilğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="212"/>
        <source>Location: %1</source>
        <translation>Konum: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="214"/>
        <source>Overrides: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Uygulama Kendiliğinden Çalıştırıcı</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>&apos;%1&apos; dosyası zaten var!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Pencere Yönetici</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Temel Ayarlar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="137"/>
        <source>Select a window manager</source>
        <translation>Bir pencere yöneticisi seçin</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Bir terminal öykünücü seçin</translation>
    </message>
    <message>
        <location filename="../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Bir web tarayıcı seçin</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Öntanımlı Uygulamalar</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Terminal Öykünümü:</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="52"/>
        <location filename="../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Web Tarayıcı:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Ortam Değişkenleri (Gelişmiş)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Değişken Adı</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Değer</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <source>LXQt Session Configuration</source>
        <translation type="vanished">LXQt Oturum Yapılandırma</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Temel Ayarlar</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Öntanımlı Uygulamalar</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="56"/>
        <source>Locations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Kendilğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Ortam (Gelişmiş)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Session Restart Required</source>
        <translation>Oturumun yeniden başlatılması gerekli</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="93"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
        <translation type="vanished">Ayarların etkin olması için masaüstü oturumunu (lxqt-session)  yeniden başlatmanız gerekli. Ana menüden çıkış işlevini kullanın.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="99"/>
        <source>Locations for Personal Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="160"/>
        <source>LXQt Session Settings - Locations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="161"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="177"/>
        <source>Choose Location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="59"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="60"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="61"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="62"/>
        <source>Public Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-session_0.14.0.orig.tar.gz: lxqt-session-0.14.0/lxqt-config-session/translations/lxqt-config-session_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Komut:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Sistem çekmecesi için bekleyin</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Uygulama Seç</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Evrensel Kendiliğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>LXQt Kendilğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Konum: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Geçersiz kılınan: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Uygulama Kendiliğinden Çalıştırıcı</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>&apos;%1&apos; dosyası zaten var!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Pencere Yönetici</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQT Modülleri</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Oturumu kapatırken sor</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="131"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="144"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Temel Ayarlar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Dur</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>Select a window manager</source>
        <translation>Bir pencere yöneticisi seçin</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../defaultappspage.cpp" line="74"/>
        <source>Select a terminal emulator</source>
        <translation>Bir terminal öykünücü seçin</translation>
    </message>
    <message>
        <location filename="../defaultappspage.cpp" line="79"/>
        <source>Select a web browser</source>
        <translation>Bir web tarayıcı seçin</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Öntanımlı Uygulamalar</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Terminal Öykünümü:</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="52"/>
        <location filename="../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Web Tarayıcı:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Ortam Değişkenleri (Gelişmiş)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Değişken Adı</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Değer</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Çalışıyor</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="45"/>
        <source>LXQt Session Settings</source>
        <translation>LXQT Oturum Ayarları</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="48"/>
        <source>Basic Settings</source>
        <translation>Temel Ayarlar</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="54"/>
        <source>Default Applications</source>
        <translation>Öntanımlı Uygulamalar</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="57"/>
        <source>User Directories</source>
        <translation>Kullanıcı Dizinleri</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="63"/>
        <source>Autostart</source>
        <translation>Kendilğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="69"/>
        <source>Environment (Advanced)</source>
        <translation>Ortam (Gelişmiş)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="95"/>
        <source>Session Restart Required</source>
        <translation>Oturumun yeniden başlatılması gerekli</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="96"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Bazı ayarlar yeniden başlayıncaya kadar etkin olmayacak.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Kişisel Dosyaların Yerleri</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQT Oturum Ayarları - Kullanıcı Dizinleri</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="186"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>%1 konumu için ayarlar uygulanırken hata oluştu</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="202"/>
        <source>Choose Location</source>
        <translation>Konum Seç</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Şablonlar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Paylaşılanlar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Müzikler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Masaüstünde gördüğünüz tüm dosyaları içerir</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>İndirilen dosyalarınızın kaydedileceği öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Şablonlarınızın kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Paylaşılan dosyalarınızın kaydedileceği öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Belgelerinizin kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Resimlerinizin kaydedileceği veya alıanacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Videolarınızın kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
</context>
</TS>
